-- User "ah" is UID 1000. He controls (as registrant) a relay domain,
-- example.net, and a virtual mailbox domain for his family,
-- family.example.net.
--
-- User "rw" is 1001, and he controls a relay domain, relay.example.org,
-- which is split between two backends. His example.org is a local
-- domain, and the machine's fully qualified domain name, also local, is
-- myhostname.example.org. His family are also system users, and
-- rw.example.org is a virtual alias domain for them. (All system users
-- have primary GID 100.) He also has two virtual mailbox domains:
-- hs.example.org and tlug.example.org.
--
-- User "rob0" is UID 1002. Okay, that's a real person (FSVO real): it
-- is me. I control example.com as a virtual alias domain.
-- relay.example.com is also mine, a relay domain, and vfd.example.com
-- is my virtual mailbox domain. Finally, whn.example.com is my wife's
-- virtual alias domain (nominally under my control, but you know how
-- that goes!) and it has ... ugh! ... a wildcard or catchall address!

PRAGMA foreign_keys=ON;
BEGIN TRANSACTION;
--
CREATE TABLE "Transport" (tpNum INTEGER PRIMARY KEY,
	active INTEGER DEFAULT 1, tpTransport TEXT, tpNexthop TEXT,
	tpMx INTEGER DEFAULT 1, tpPort INTEGER,
	UNIQUE (tpTransport,tpNexthop,tpMx,tpPort));
-- negative transNum are various standard transports with no nexthop
-- INSERT INTO "Transport" VALUES(-6,1,'dovecot',NULL,1,NULL);
INSERT INTO "Transport" VALUES(-5,1,'smtp',NULL,1,NULL);
INSERT INTO "Transport" VALUES(-4,1,'virtual',NULL,1,NULL);
INSERT INTO "Transport" VALUES(-3,1,'lmtp',NULL,1,NULL);
INSERT INTO "Transport" VALUES(-2,1,'relay',NULL,1,NULL);
INSERT INTO "Transport" VALUES(-1,1,'local',NULL,1,NULL);
-- zero is the special ":" entry which means "use standard transport for
-- that domain and standard routing procedure" (MX, normally). This
-- could be used in Addresses to override a transport set for a domain.
INSERT INTO "Transport" VALUES(0,1,'','',1,NULL);
INSERT INTO "Transport" VALUES(1,1,NULL,'relay.example.org',0,1025);
INSERT INTO "Transport" VALUES(2,1,NULL,'hairy.example.org',1,NULL);
INSERT INTO "Transport" VALUES(3,1,NULL,'example.net',0,NULL);
INSERT INTO "Transport" VALUES(4,1,'custom','custom.example.com',1,2525);
INSERT INTO "Transport" VALUES(5,1,NULL,'custom.example.com',1,NULL);
INSERT INTO "Transport" VALUES(6,1,NULL,'no-mx.example.net',0,NULL);
INSERT INTO "Transport" VALUES(7,1,'smtp','no-mx.example.edu',0,587);
INSERT INTO "Transport" VALUES(8,1,'throttled',NULL,1,NULL);
--
CREATE TABLE "RClass" (rcNum INTEGER PRIMARY KEY,
	rcName TEXT NOT NULL, UNIQUE(rcName));
--
INSERT INTO "RClass" VALUES(0,'reject');
INSERT INTO "RClass" VALUES(1,'nuts');
INSERT INTO "RClass" VALUES(10,'aggressive');
INSERT INTO "RClass" VALUES(20,'moderate');
INSERT INTO "RClass" VALUES(29,'whn');
INSERT INTO "RClass" VALUES(30,'conservative');
INSERT INTO "RClass" VALUES(40,'weak');
INSERT INTO "RClass" VALUES(50,'open');
--
CREATE TABLE "Domain" (domNum INTEGER PRIMARY KEY,
	domName TEXT NOT NULL,
	active INTEGER DEFAULT 1, domClass INTEGER DEFAULT 0,
	domSysUser INTEGER DEFAULT 0, domTpNum INTEGER,
	domRcNum INTEGER DEFAULT 30, UNIQUE (domName),
	FOREIGN KEY(domTpNum) REFERENCES Transport(tpNum)
	FOREIGN KEY(domRcNum) REFERENCES RClass(rcNum));
--
INSERT INTO "Domain" VALUES(1,'localhost',1,1,0,NULL,0);
INSERT INTO "Domain" VALUES(2,'localhost.myhostname.example.org',1,1,0,NULL,0);
INSERT INTO "Domain" VALUES(3,'myhostname.example.org',1,1,0,NULL,1);
INSERT INTO "Domain" VALUES(4,'example.org',1,1,1001,NULL,10);
INSERT INTO "Domain" VALUES(5,'relay.example.org',1,2,1001,1,20);
INSERT INTO "Domain" VALUES(6,'example.net',1,2,1000,3,30);
INSERT INTO "Domain" VALUES(7,'family.example.net',1,801,1000,NULL,20);
INSERT INTO "Domain" VALUES(8,'rw.example.org',1,3,1001,NULL,20);
INSERT INTO "Domain" VALUES(9,'hs.example.org',1,802,1001,NULL,20);
INSERT INTO "Domain" VALUES(10,'tlug.example.org',1,802,1001,NULL,20);
INSERT INTO "Domain" VALUES(11,'example.com',1,3,1002,NULL,20);
INSERT INTO "Domain" VALUES(12,'relay.example.com',1,2,1002,4,20);
INSERT INTO "Domain" VALUES(13,'vfd.example.com',1,803,1002,NULL,40);
INSERT INTO "Domain" VALUES(14,'whn.example.com',1,3,1002,NULL,20);
-- external domains, used as virtual alias targets
INSERT INTO "Domain" VALUES(15,'example.info',1,0,0,NULL,NULL);
INSERT INTO "Domain" VALUES(16,'example.edu',1,0,0,NULL,NULL);
-- external domain, used as transport targets
INSERT INTO "Domain" VALUES(17,'y.example.com',1,0,0,8,NULL);
--
CREATE TABLE "Address" (addNum INTEGER PRIMARY KEY,
	addLocalpart TEXT NOT NULL, addDomNum INTEGER NOT NULL,
	active INTEGER DEFAULT 1, addTpNum INTEGER, addRcNum INTEGER,
	FOREIGN KEY(addDomNum) REFERENCES Domain(domNum),
	FOREIGN KEY(addTpNum) REFERENCES Transport(tpNum),
	FOREIGN KEY(addRcNum) REFERENCES RClass(rcNum),
	UNIQUE (addLocalpart, addDomNum));
-- 3: myhostname.example.org ($myhostname, local accounts and aliases)
INSERT INTO "Address" VALUES(1,'postmaster',3,1,NULL,40);
INSERT INTO "Address" VALUES(2,'abuse',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(3,'ah',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(4,'rw',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(5,'rob0',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(6,'m1',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(7,'m2',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(8,'m3',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(9,'whn',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(10,'kid0',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(11,'kid1',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(12,'kid2',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(13,'root',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(14,'bin',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(15,'daemon',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(16,'MAILER-DAEMON',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(17,'named',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(18,'operator',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(19,'www',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(20,'us',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(21,'rob+list',3,1,NULL,NULL);
INSERT INTO "Address" VALUES(22,'command.example',3,1,NULL,NULL);
-- 4: example.org, also being local, is not needed unless per-address
--    transports or smtpd restrictions are desired
--
-- 5: relay.example.org
INSERT INTO "Address" VALUES(23,'postmaster',5,1,NULL,40);
INSERT INTO "Address" VALUES(24,'abuse',5,1,NULL,NULL);
INSERT INTO "Address" VALUES(25,'tom',5,1,NULL,NULL);
INSERT INTO "Address" VALUES(26,'dick',5,1,NULL,NULL);
-- Harry runs his own mailserver and tolerates NO spam
INSERT INTO "Address" VALUES(27,'harry',5,1,2,1);
-- 6: example.net (relay)
INSERT INTO "Address" VALUES(28,'postmaster',6,1,NULL,40);
INSERT INTO "Address" VALUES(29,'abuse',6,1,NULL,NULL);
INSERT INTO "Address" VALUES(30,'beth',6,1,NULL,NULL);
INSERT INTO "Address" VALUES(31,'sally',6,1,NULL,NULL);
INSERT INTO "Address" VALUES(32,'kathy',6,1,NULL,NULL);
-- 7: family.example.net (VM)
INSERT INTO "Address" VALUES(33,'postmaster',7,1,NULL,40);
INSERT INTO "Address" VALUES(34,'abuse',7,1,NULL,NULL);
INSERT INTO "Address" VALUES(35,'alan',7,1,NULL,NULL);
INSERT INTO "Address" VALUES(36,'daddy',7,1,NULL,NULL);
INSERT INTO "Address" VALUES(37,'mama',7,1,NULL,NULL);
INSERT INTO "Address" VALUES(38,'sissy',7,1,NULL,NULL);
INSERT INTO "Address" VALUES(39,'boy',7,1,NULL,NULL);
-- 8: rw.example.org (VA)
INSERT INTO "Address" VALUES(40,'postmaster',8,1,NULL,NULL);
INSERT INTO "Address" VALUES(41,'abuse',8,1,NULL,NULL);
INSERT INTO "Address" VALUES(42,'rw',8,1,NULL,NULL);
INSERT INTO "Address" VALUES(43,'m1',8,1,NULL,NULL);
INSERT INTO "Address" VALUES(44,'m2',8,1,NULL,NULL);
INSERT INTO "Address" VALUES(45,'m3',8,1,NULL,NULL);
-- 9: hs.example.org (VM)
INSERT INTO "Address" VALUES(46,'postmaster',9,1,NULL,NULL);
INSERT INTO "Address" VALUES(47,'abuse',9,1,NULL,NULL);
INSERT INTO "Address" VALUES(48,'mr.rw',9,1,NULL,NULL);
INSERT INTO "Address" VALUES(49,'anna',9,1,NULL,NULL);
INSERT INTO "Address" VALUES(50,'joey',9,1,NULL,NULL);
INSERT INTO "Address" VALUES(51,'susie',9,1,NULL,NULL);
-- 10: tlug.example.org (VM)
INSERT INTO "Address" VALUES(52,'postmaster',10,1,NULL,NULL);
INSERT INTO "Address" VALUES(53,'abuse',10,1,NULL,NULL);
INSERT INTO "Address" VALUES(54,'rw',10,1,NULL,NULL);
INSERT INTO "Address" VALUES(55,'geek1',10,1,NULL,NULL);
INSERT INTO "Address" VALUES(56,'geek2',10,1,NULL,NULL);
-- 11: example.com (VA)
INSERT INTO "Address" VALUES(57,'postmaster',11,1,NULL,NULL);
INSERT INTO "Address" VALUES(58,'abuse',11,1,NULL,NULL);
INSERT INTO "Address" VALUES(59,'rob0',11,1,NULL,NULL);
INSERT INTO "Address" VALUES(60,'info',11,1,NULL,NULL);
INSERT INTO "Address" VALUES(61,'jobs',11,1,NULL,NULL);
-- 12: relay.example.com (relay)
INSERT INTO "Address" VALUES(62,'postmaster',12,1,NULL,NULL);
INSERT INTO "Address" VALUES(63,'abuse',12,1,NULL,NULL);
-- heavily-spammed webmaster needs aggressive spam protection
INSERT INTO "Address" VALUES(64,'webmaster',12,1,NULL,10);
INSERT INTO "Address" VALUES(65,'manager',12,1,NULL,NULL);
INSERT INTO "Address" VALUES(66,'foreman1',12,1,NULL,NULL);
INSERT INTO "Address" VALUES(67,'foreman2',12,1,NULL,NULL);
INSERT INTO "Address" VALUES(68,'foreman3',12,1,NULL,NULL);
-- techie has her own mail server
INSERT INTO "Address" VALUES(69,'techie',12,1,5,NULL);
-- 13: vfd.example.com (VM)
INSERT INTO "Address" VALUES(70,'postmaster',13,1,NULL,NULL);
INSERT INTO "Address" VALUES(71,'abuse',13,1,NULL,NULL);
INSERT INTO "Address" VALUES(72,'rob0',13,1,NULL,NULL);
INSERT INTO "Address" VALUES(73,'chief',13,1,NULL,NULL);
INSERT INTO "Address" VALUES(74,'asst-chief',13,1,NULL,NULL);
INSERT INTO "Address" VALUES(75,'capt',13,1,NULL,NULL);
INSERT INTO "Address" VALUES(76,'secretary',13,1,NULL,NULL);
INSERT INTO "Address" VALUES(77,'tim',13,1,NULL,NULL);
INSERT INTO "Address" VALUES(78,'jason',13,1,NULL,NULL);
INSERT INTO "Address" VALUES(79,'tom',13,1,NULL,NULL);
INSERT INTO "Address" VALUES(80,'lisa',13,1,NULL,NULL);
-- 14: whn.example.com (VA, wildcard - yuck)
INSERT INTO "Address" VALUES(81,'postmaster',14,1,NULL,10);
INSERT INTO "Address" VALUES(82,'abuse',14,1,NULL,NULL);
INSERT INTO "Address" VALUES(83,'rob0',14,1,NULL,10);
INSERT INTO "Address" VALUES(84,'whn',14,1,NULL,NULL);
-- this is the wildcard entry
INSERT INTO "Address" VALUES(85,'',14,1,NULL,NULL);
-- external domains, used as virtual alias targets
INSERT INTO "Address" VALUES(86,'alien',15,1,NULL,NULL);
INSERT INTO "Address" VALUES(87,'martian',16,1,NULL,NULL);
-- sample disabled login system account
INSERT INTO "Address" VALUES(88,'virus',3,-1,NULL,NULL);
-- sample disabled login virtual account
INSERT INTO "Address" VALUES(89,'dewayne',13,-1,NULL,NULL);
--
CREATE TABLE "Alias" (aliasKey INTEGER PRIMARY KEY,
	aliasNum INTEGER NOT NULL,
	active INTEGER DEFAULT 1, aliasTarget TEXT NOT NULL,
	FOREIGN KEY(aliasNum) REFERENCES Address(addNum));
--
INSERT INTO "Alias" (aliasNum, active, aliasTarget) VALUES(1,1,'root@myhostname.example.org');
INSERT INTO "Alias" (aliasNum, active, aliasTarget) VALUES(2,1,'postmaster@myhostname.example.org');
INSERT INTO "Alias" (aliasNum, active, aliasTarget) VALUES(13,1,'us@myhostname.example.org');
INSERT INTO "Alias" (aliasNum, active, aliasTarget) VALUES(14,1,'root@myhostname.example.org');
INSERT INTO "Alias" (aliasNum, active, aliasTarget) VALUES(15,1,'root@myhostname.example.org');
INSERT INTO "Alias" (aliasNum, active, aliasTarget) VALUES(16,1,'postmaster@myhostname.example.org');
INSERT INTO "Alias" (aliasNum, active, aliasTarget) VALUES(17,1,'root@myhostname.example.org');
INSERT INTO "Alias" (aliasNum, active, aliasTarget) VALUES(18,1,'root@myhostname.example.org');
INSERT INTO "Alias" (aliasNum, active, aliasTarget) VALUES(19,1,'root@myhostname.example.org');
INSERT INTO "Alias" (aliasNum, active, aliasTarget) VALUES(21,1,'rob0-list@myhostname.example.org');
INSERT INTO "Alias" (aliasNum, active, aliasTarget) VALUES(20,1,'rob0-root@myhostname.example.org');
INSERT INTO "Alias" (aliasNum, active, aliasTarget) VALUES(20,1,'rw-root@myhostname.example.org');
INSERT INTO "Alias" (aliasNum, active, aliasTarget) VALUES(20,0,'ah-root@myhostname.example.org');
INSERT INTO "Alias" (aliasNum, active, aliasTarget) VALUES(22,1,'"|echo `/bin/date` command.example mail received >> /tmp/command.example.log"');
--
CREATE TABLE "VAlias" (vaKey INTEGER PRIMARY KEY,
	vaNum INTEGER NOT NULL,
	active INTEGER DEFAULT 1, vaTargetNum INTEGER NOT NULL,
	vaTargetExt TEXT,
	FOREIGN KEY(valiasNum) REFERENCES Address(addNum),
	FOREIGN KEY(vaTargetNum) REFERENCES Address(addNum));
-- 5: relay.example.org 23-27
-- 6: example.net (relay) 28-32
-- 7: family.example.net (VM) 33-39
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(33,1,35,NULL);
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(34,1,35,NULL);
-- 8: rw.example.org (VA) 40-45
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(40,1,4,NULL);
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(40,1,5,'pm+rw');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(41,1,4,NULL);
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(42,1,4,NULL);
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(43,1,6,NULL);
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(44,1,7,NULL);
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(45,1,8,NULL);
-- 9: hs.example.org (VM) 46-51
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(46,1,4,NULL);
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(46,1,5,'pm+hs');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(47,1,4,NULL);
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(48,0,4,NULL);
-- 10: tlug.example.org (VM) 52-56
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(52,1,4,NULL);
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(52,1,5,'pm+tl');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(53,1,4,NULL);
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(54,1,4,NULL);
-- 11: example.com (VA) 57-61
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(57,1,5,'pm+ex');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(58,1,5,'ab+ex');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(58,1,69,'ab');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(59,1,4,'ex');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(60,1,65,'info');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(60,1,68,'info');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(60,1,86,'info');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(61,1,65,'jobs');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(61,1,67,'jobs');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(61,1,87,'jobs');
-- 12: relay.example.com (relay) 62-69
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(62,1,5,'pm+ex');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(63,1,5,'ab+ex');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(63,1,69,'ab');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(64,1,69,'webm');
-- 13: vfd.example.com (VM) 70-80
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(70,1,5,'pm+vfd');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(71,1,5,'ab+vfd');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(72,1,5,'vfd');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(73,1,77,'vfd');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(73,0,89,'vfd');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(74,1,78,'vfd');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(74,0,89,'vfd');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(75,1,79,'vfd');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(76,1,80,'vfd');
-- 14: whn.example.com (VA, wildcard - yuck) 81-85
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(81,1,5,'pm+whn');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(82,1,5,'ab+whn');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(83,1,5,'whn');
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(84,1,9,NULL);
INSERT INTO "VAlias" (vaNum, active, vaTargetNum, vaTargetExt) VALUES(85,1,9,'wildcard');
-- external domains, used as virtual alias targets 86,87
--
CREATE TABLE "VMailbox" (vmNum INTEGER PRIMARY KEY,
	active INTEGER DEFAULT 1, vmPasswd TEXT, vmHome TEXT,
	vmUid INTEGER, vmGid INTEGER,
	FOREIGN KEY(vmNum) REFERENCES Address(addNum));
--
-- this first one delivers to local user "ah", vmPasswd is NULL
INSERT INTO "VMailbox" VALUES(35,1,NULL,'ah/family',1000,100);
INSERT INTO "VMailbox" VALUES(36,1,'{PLAIN}GiveDaddyHisMail!',NULL,NULL,NULL);
INSERT INTO "VMailbox" VALUES(37,1,'{PLAIN}GiveMamaHerMail!',NULL,NULL,NULL);
INSERT INTO "VMailbox" VALUES(38,1,'{PLAIN}GiveSissyHerMail!',NULL,NULL,NULL);
INSERT INTO "VMailbox" VALUES(39,1,'{PLAIN}GiveBoyHisMail!',NULL,NULL,NULL);
-- this delivers to "rw", but is accessible with alternate credentials
INSERT INTO "VMailbox" VALUES(48,1,'{PLAIN}BB+JiLAStU1HP9Ql','rw/tchs',1001,100);
INSERT INTO "VMailbox" VALUES(49,1,'{PLAIN}dr0wss@p',NULL,NULL,NULL);
INSERT INTO "VMailbox" VALUES(50,1,'{PLAIN}0wss@pdr',NULL,NULL,NULL);
INSERT INTO "VMailbox" VALUES(51,1,'{PLAIN}ss@pdr0w',NULL,NULL,NULL);
INSERT INTO "VMailbox" VALUES(55,1,'{PLAIN}weakPassword',NULL,NULL,NULL);
INSERT INTO "VMailbox" VALUES(56,1,'{PLAIN}n0t@sWeakPaswurD',NULL,NULL,NULL);
--
CREATE TABLE "BScat" (bsKey INTEGER PRIMARY KEY,
	bsSender TEXT NOT NULL, bsPriority INTEGER,
	bsTarget TEXT NOT NULL, UNIQUE (bsSender, bsPriority));
--
INSERT INTO "BScat" VALUES(1,'<>',1,'z-semBscat');
INSERT INTO "BScat" VALUES(2,'<>',2,'z-bscatOrg');
INSERT INTO "BScat" VALUES(3,'postmaster',1,'z-semBscat');
INSERT INTO "BScat" VALUES(4,'postmaster',2,'z-bscatOrg');
INSERT INTO "BScat" VALUES(5,'mailer-daemon',1,'z-semBscat');
INSERT INTO "BScat" VALUES(6,'mailer-daemon',2,'z-bscatOrg');
-- end!
COMMIT;
